==> QupZilla-2.0.0.tar.xz: QupZilla-2.0.0/src/plugins/StatusBarIcons/translations/nqo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nqo" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>ߖߌ߬ߦߊ ߡߊߝߊ߬ߟߋ߲߬ ߞߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬ ߟߊߦߟߍ߬ ߞߍߦߙߐ ߟߎ߫ ߡߊ߬ ߞߌߢߍ߲߫ ߘߐ߫</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current page settings</source>
        <translation>ߛߋ߲߬ߠߊ߬ ߞߐߜߍ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>ߖߌ߬ߦߊ߬ ߟߊߦߟߍ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>ߖߌ߬ߦߊ߬ ߟߊߦߟߍ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global settings</source>
        <translation>ߝߘߏ߬ߓߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>ߖߌ߬ߦߊ ߟߎ߫ ߖߘߍ߬ߡߊ߬ ߟߊ߬ߦߟߍ߬ߟߌ</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>ߖ߭ߝ߭ߊߣߐ߬ߣߐ߬ߟߊ ߡߊߝߊ߬ߟߋ߲߬ ߞߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬ ߟߊߦߟߍ߬ ߞߍߦߙߐ ߟߎ߫ ߡߊ߬ ߞߌߢߍ߲߫ ߘߐ߫</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="48"/>
        <source>Current page settings</source>
        <translation>ߛߋ߲߬ߠߊ߬ ߞߐߜߍ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="63"/>
        <source>Global settings</source>
        <translation>ߝߘߏ߬ߓߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="64"/>
        <source>Manage JavaScript settings</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߫ ߞߎ߲߬ߠߊߛߌ߰</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Proxy configuration</source>
        <translation>ߕߍߟߐ ߢߊߘߐߦߊߟߌ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Select proxy</source>
        <translation>ߕߍߟߐ ߓߊߕߐߡߐ߲߫</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="82"/>
        <source>Empty</source>
        <translation>ߘߐߞߏߟߏ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="86"/>
        <source>Manage proxies</source>
        <translation>ߕߍߟߐ ߞߎ߲߬ߠߊߛߌ߰</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="99"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>ߞߙߏ߬ߝߏ ߛߌ߰ߞߊ߲ ߠߊߟߐ߲߫ ߊ߬ ߣߌ߫ ߞߊ߬ ߕߍߟߐ ߞߎ߲߬ߠߊߛߌ߰&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ߞߙߏ߬ߝߏ:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ߕߍߟߐ:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="102"/>
        <source>Connected</source>
        <translation>ߜߊ߲߬ߞߎ߲߬ߣߍ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="105"/>
        <source>Offline</source>
        <translation>ߜߊ߲߬ߞߎ߲߬ߓߐ߬ߣߍ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>System proxy</source>
        <translation>ߞߊ߲ߞߋ ߕߍߟߐ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>No proxy</source>
        <translation>ߕߍߟߐ ߕߍ߫</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>ߕߍߟߐ ߖߘߍ߬ ߢߊ߬ߘߐ߬ߦߊ߬ߟߊ ߕ.ߖ.ߢ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="122"/>
        <source>User defined</source>
        <translation>ߡߊߕߍ߰ߣߍ߲ ߕߣߐ߬ߓߐ߬ߟߊ ߓߟߏ߫</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>ߕߍߟߐ ߞߎ߲߬ߠߊ߬ߛߌ߰ߟߊ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>ߕߍߟߐ ߓߊߕߐߡߐ߲߫:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>ߕߍߟߐ ߝߙߊ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>ߕߍߟߐ ߖߐ߬ߛߌ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>ߕߍߟߐ ߕߍ߫ ߦߋ߲߬. ߌ ߘߌ߫ ߛߋ߫ ߕߍߟߐ ߝߙߊ߬ ߟߊ߫ ߊ߬ ߛߐ߲߬ߞߌ߲ ߘߐ߫ &lt;b&gt;ߊ߬ ߝߙߊ߬&lt;/b&gt; ߞߎ߬ߘߎ ߞߊ߲߬.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>ߡߝߊ߬ߟߋ߲߬ߠߌ ߠߎ߬ ߞߊ߫ ߞߊ߲߫ ߞߊ߬ ߟߊߡߊ߲߬ߘߌ߫ &lt;b&gt;ߊ߬ ߟߊߞߎ߲߬ߘߎ߬&lt;/b&gt; ߞߎ߬ߘߎ ߟߋ߬ ߟߊ߫.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>ߕߍߟߐ ߕߐ߮:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>ߛߋ߲߬ߠߊ߬ ߕߍߟߐ ߖߐ߬ߛߌ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>ߦߴߊ߬ ߝߍ߬ ߞߊ߬ ߛߋ߲߬ߠߊ߬ ߕߍߟߐ ߖߐ߬ߛߌ߫ ߟߋ߬ ߢߍ؟</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>ߛߓߍߟߝߊߕߊ</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>ߕߍߟߐ ߞߊ߫ ߟߊߓߊ߯ߙߊ߫</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>ߕߍߟߐ߫ ߜߘߍ߫ ߟߊߓߊ߯ߙߊ߫ ߞߟߏߜߍ߫ ߛߘߌߜߋ߲ ߟߊߕߊ߯ ߝߐߞߊ߲ ߠߊߞߊ߲ߘߊߣߍ߲ ߜߊ߲߬ߞߎ߲߬ߠߌ ߢߍ߫</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;ߢߌ߬ߣߊ߬ߓߐ߬ߕߊ ߟߎ߬&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>ߊ߬ ߞߊ߫ ߟߊߓߊ߯ߙߊ߫ ߣߌ߲߬ ߞߊ߲߬:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>ߞߟߏߜߍ߫ ߛߘߌߜߋ߲ ߟߊߕߊ߯ ߝߐߞߊ߲</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>ߜߊ߬ߔߐ߬ߍ߬ߘߐ߬ ߅</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>ߥߏ߬ߘߊ:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>ߟߐ߲ߕߐ߮:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>ߕߊ߬ߡߌ߲߬ߞߊ߲:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>ߛߓߍߢߌ߲ ߠߊߓߊ߯ߙߊ߫ ߞߍߒߖߘߍߡߊ ߢߊߘߐߦߊߟߌ ߢߍ߫</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>ߞߊ߲ߞߋ ߟߊ߫ ߕߍߟߐ ߢߊߘߐߦߊߟߌ</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>ߕߍߟߐ ߖߘߍ߬ ߢߊ߬ߘߐ߬ߦߊ߬ߟߊ ߞߐߕߐ߯ߘߐ</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>ߓߟߏߟߊ߫ ߢߊߘߐߦߊߟߌ</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>ߛߐߘߊ:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߕߐ߯ߡߊߦߋߙߋ߲&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>ߕߐ߯ߡߊߦߋߙߋ߲ ߢߌ߲߬ ߠߎ߬ ߘߌ߫ ߟߊߟߐ߲߫ ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߘߐ߫:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>ߖߌ߬ߦߊ ߟߎ߬ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>ߞߙߏ߬ߝߏ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>ߡߊ߬ߞߊ߬ߟߌ߬ ߓߊ߲ߓߊ߲ߣߍ߲</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>ߡߊ߬ߞߊ߬ߟߌ: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.1.2.tar.xz: QupZilla-2.1.2/src/plugins/StatusBarIcons/translations/nqo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nqo" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>ߖߌ߬ߦߊ ߡߊߝߊ߬ߟߋ߲߬ ߞߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬ ߟߊߦߟߍ߬ ߞߍߦߙߐ ߟߎ߫ ߡߊ߬ ߞߌߢߍ߲߫ ߘߐ߫</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>ߖߌ߬ߦߊ߬ ߟߊߦߟߍ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>ߖߌ߬ߦߊ߬ ߟߊߦߟߍ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>ߖߌ߬ߦߊ ߟߎ߫ ߖߘߍ߬ߡߊ߬ ߟߊ߬ߦߟߍ߬ߟߌ</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>ߖ߭ߝ߭ߊߣߐ߬ߣߐ߬ߟߊ ߡߊߝߊ߬ߟߋ߲߬ ߞߊ߬ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߬ ߟߊߦߟߍ߬ ߞߍߦߙߐ ߟߎ߫ ߡߊ߬ ߞߌߢߍ߲߫ ߘߐ߫</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߓߐ߫ ߊ߬ ߟߊ߫ (ߕߎ߬ߡߊ ߘߏ߫ ߟߊ߫)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߞߐߕߐ߯ߘߐߛߙߋ ߟߎ߫ ߞߎ߲߬ߠߊߛߌ߰</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>ߕߍߟߐ ߓߊߕߐߡߐ߲߫</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>ߘߐߞߏߟߏ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>ߕߍߟߐ ߞߎ߲߬ߠߊߛߌ߰</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>ߞߙߏ߬ߝߏ ߛߌ߰ߞߊ߲ ߠߊߟߐ߲߫ ߊ߬ ߣߌ߫ ߞߊ߬ ߕߍߟߐ ߞߎ߲߬ߠߊߛߌ߰&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ߞߙߏ߬ߝߏ:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ߕߍߟߐ:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>ߜߊ߲߬ߞߎ߲߬ߣߍ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>ߜߊ߲߬ߞߎ߲߬ߓߐ߬ߣߍ߲</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>ߞߊ߲ߞߋ ߕߍߟߐ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>ߕߍߟߐ ߕߍ߫</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>ߡߊߕߍ߰ߣߍ߲ ߕߣߐ߬ߓߐ߬ߟߊ ߓߟߏ߫</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>ߕߍߟߐ ߞߎ߲߬ߠߊ߬ߛߌ߰ߟߊ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>ߕߍߟߐ ߓߊߕߐߡߐ߲߫:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>ߕߍߟߐ ߝߙߊ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>ߕߍߟߐ ߖߐ߬ߛߌ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>ߕߍߟߐ ߕߍ߫ ߦߋ߲߬. ߌ ߘߌ߫ ߛߋ߫ ߕߍߟߐ ߝߙߊ߬ ߟߊ߫ ߊ߬ ߛߐ߲߬ߞߌ߲ ߘߐ߫ &lt;b&gt;ߊ߬ ߝߙߊ߬&lt;/b&gt; ߞߎ߬ߘߎ ߞߊ߲߬.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>ߡߝߊ߬ߟߋ߲߬ߠߌ ߠߎ߬ ߞߊ߫ ߞߊ߲߫ ߞߊ߬ ߟߊߡߊ߲߬ߘߌ߫ &lt;b&gt;ߊ߬ ߟߊߞߎ߲߬ߘߎ߬&lt;/b&gt; ߞߎ߬ߘߎ ߟߋ߬ ߟߊ߫.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>ߕߍߟߐ ߕߐ߮:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>ߛߋ߲߬ߠߊ߬ ߕߍߟߐ ߖߐ߬ߛߌ߬</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>ߛߓߍߟߝߊߕߊ</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>ߞߟߏߜߍ߫ ߛߘߌߜߋ߲ ߟߊߕߊ߯ ߝߐߞߊ߲</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>ߜߊ߬ߔߐ߬ߍ߬ߘߐ߬ ߅</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>ߥߏ߬ߘߊ:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>ߟߐ߲ߕߐ߮:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>ߕߊ߬ߡߌ߲߬ߞߊ߲:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߕߐ߯ߡߊߦߋߙߋ߲&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>ߕߐ߯ߡߊߦߋߙߋ߲ ߢߌ߲߬ ߠߎ߬ ߘߌ߫ ߟߊߟߐ߲߫ ߛߌ߰ߞߊ߲߬ ߡߙߎߝߋ ߘߐ߫:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>ߖߌ߬ߦߊ ߟߎ߬ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>ߖ߭ߝ߭ߊߣߐߣߐߟߊ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>ߞߙߏ߬ߝߏ ߕߐ߯ߡߊߦߋߙߋ߲</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>ߡߊ߬ߞߊ߬ߟߌ߬ ߓߊ߲ߓߊ߲ߣߍ߲</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>ߡߊ߬ߞߊ߬ߟߌ: %1%</translation>
    </message>
</context>
</TS>
